bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 5. Aventiure
___________________________________________________
| ### MAN SACH si tægelichen nv riten anden Rin ### die cer hohgecite gerne wolden sin ### di dvrch des kvneges liebe chômn in daz lant ### den bot man svemelichen ross vn– herlich gewant ### In was ir gesidele allen wol bereit ### den hoehsten vn– den besten als vns daz ist geseit ### zwein vn– drizech fvrsten da cer hohgecit ### da cierten sich engegene di scoenen frovwen wider strit
###### 265 | ### Ez was da vil vnmvezech Giselher daz chint ### di geste mit den chvnden vil gvetelich sint ### di enpfienger vnd Gernot vn– ovch ir beider man ### ia grvozten si di degene als ez nach ern was getan
###### 266 | ### Vil golt roter sætele si fvorten in daz lant ### zierliche scilde vn– herlich gewant ### brahten si ze [302b] Rine zvo der hohgecit ### manegen vngesvnden sah man vroelichen sit
###### 267 | ### Die in den betten lagen vn– heten wnden not ### di mvosen des vergezzen wi herte was der tot ### di siechen vngesvnden mvosen si verchlagn ### si vrevten sich der mære gein der hohgecite tagn
###### 268 | ### wie si lebn wolden da cer wirtscaft ### wnne ane maze mit vrevden vberchraft ### heten al die livte swaz man ir da vant ### des hvop sich michel vrevde vber al daz Gvnthers lant
| ### An einem pfinxt morgen sah man fvere gan ### gechleidet wnnechliche vil manegen chvenen man ### fvnf tvsent oder mere da cer hohgecit ### sich hvop div chvrcewile an manegem ende wider strit
###### 270 | ### Der wirt der hete di sinne im was daz wol erchânt ### wi rehte hercenliche der helt von Niderlant ### sine swester trvote swi er si niene gesach ### der man so grozer scoene vor allen ivnchfrovwen iach
###### 271 | ### Do sprach zvo dem kvnege der degen Oertwin ### welt ir mit vollen eren cer hohgecite sin ### so svlt ir lazen scovwen div wnnechlichen kint ### di mit so grozen eren hie cen Bvrgonden sint
###### 272 | ### Waz wære mannes wenne des vrevte sich sin lip ### ez entæten scoene mægede vn– herlichiv wip ### lazet iwer swester fver iwer geste gan ### der rat der was ce liebe manegem helde getan
| ### Des wil ich gerne volgen sprach der kvnech do ### alle di ez erfvnden di warens harte vro ### ern bot ez frovwen voten vn– ir tohter wolgetan ### daz si mit ir mageden hince hove solden gan
###### 274 | ### Do wart voz den schrinen gesvochet gvot gewant ### swaz man inder valde der edelen wæte vant ### di bovge mit den porten des was in vil bereit ### sich cierte flizechliche vil manech wætlichiv meit
###### 275 | ### Vil manech reche tvmber des tages hete mvot ### daz er an cesehene den frovwen wære gvot ### daz er da fver niht næme eins richen kvneges lant ### si sahen di vil gerne di si nie heten bechant
| ### Do hiez der kvnec riche mit siner swester gan ### di ir dienen solden wol hvndert siner man ### ir vn– siner mage di trvogen swert en hant ### daz was daz hovegesinde von der Bvrgonden lant
###### 277 | ### voten di vil richen di sach man mit ir chomn ### div hete scoene vrovwen gesellechlich genomn ### wol hvndert oder mere di trvogen richiv chleit ### ovch gie da nach ir tohter vil manech wætlichiv meit
###### 278 | ### Von einer chemenaten sah man si alle gan ### do wart vil michel dringen von heldn dar getan ### di des gedingen heten ob chvnde [303a] daz gescehn ### daz si di maget edele solden vroeliche sehn
| ### <Nv> gie div minnecliche also der morgen rot ### tvot voz den trveben wolchen da sciet von maneger not ### der si da trvog inhercen vn– lange het getan ### er sach di minnechlichen nv vil herlichen stan
###### 280 | ### Ia lv^hte ir von ir wæte vil manech edel stein ### ir rosen rotiv varwe vil minnechlen scein ### ob iemem wnscen solde der chvnde niht ge iehn ### daz er ce dirre werelde het iht scoeners gesehn
###### 281 | ### Sam der liehte mane vor den sternen stat ### der scin so lvoterliche ab den wolchen gat ### dem stvont si nv geliche vor maneger frovwen gvot ### des wart da wol gehoehet den zieren helden der mvot
###### 282 | ### Die richen chamerære sah man vor ir gan ### di hohgemvoten degene diene wolden daz niht lan ### sine drvngen da si sahen di minechlichen meit ### Sivride dem herrn wart beide lieb vnd leit
| ### <Er> daht in sinem mvote wi chvnde daz ergan ### daz ich dich minnen solde daz ist ein tvmber wan ### sol aber ich dich vremeden so wære ich sanfter tot ### er wart von den gedanchen vil diche bleich vnd rot
###### 284 | ### Do stvont so minnechliche daz Sigmvndes chint ### sam er entworfen wære an ein Permint ### von gvotes meisters listen also man im iach ### daz man helt deheinen nie so scoenen gesach
###### 285 | ### Die mit den frovwen giengen di hiezen von den wegen ### wichen allenthalben daz leiste manech degen ### div hohe tragenden hercen vrevten manegen lip ### man sach in hohen zvehten manech herlichez wip
| ### Do sprach von Bvrgonden der herre Gernot ### der iv sinen dienest so gvetlichen bot ### Gvnther vil lieber brvoder dem svlt ir tvon alsam ### vor allen disen rechen des rates ich nimmer mich gescam
###### 287 | ### Ir heizet Sivride zvo miner swester chvmn ### daz in div maget grveze des hab wir immer frvmn ### div nie gegrvezte rechen div sol in grvezen pflegn ### da mit wir habn gewnnen den vil cierlichen degn
###### 288 | ### Do giengens wirtes mage da man den helt vant ### si sprachen zvo dem rechen vozer Niderlant ### iv hat der kvnech erlovbet ir svlt ce hove gan ### sin swester sol ivch grvezen <daz> ist cen eren iv getan
###### 289 | ### Der herre in sinem mvote was des vil gemeit ### do trvog er ime hercen lieb ane leit ### daz er sehen solde der scoenen voten kint ### mit [303b] minnechlichen tvgenden si grvozte Sivride sint
| ### <Do> si den hohgemvoten vor ir <stende> sach ### do erzvnde sich sin varwe div scoene magt sprach ### sit willechomn her Sivrit ein edel riter gvot ### do wart im von dem grvoze vil wol gehoehet der mvot
###### 291 | ### Er neig ir flizechliche bi der hende si in vie ### wie rehte minnechliche er bi der frovwen gie ### mit lieben ovgen blichen ein ander sahen an ### der herre vn– ovch div frovwe daz wart vil tovgenlich getan
###### 292 | ### Wart iht da friwentliche getwngen wiziv hant ### von hercenlieber minne daz ist mir niht bechant ### doch enchan ich niht gelovbn daz ez wrde lan ### si het im holden willen chvnt vil sciere getan
###### 293 | ### Bi der svmmer cite vn– gein des meien tagn ### dorft er in sime hercen nimmer mer getragn ### so vil der hohen vrevde denn er da gewan ### do im div gie enhende di er ce trvote wolde han
| ### Do gedahte manech reche hey wær mir sam gescehen ### daz ich ir gienge nebene sam ich in han gesehen ### oder bi ce ligene daz liez ich ane haz ### ez engediente noch nie reche nach einer kvneginne baz
###### 295 | ### Von swelher chvnege lande di geste chômn dar ### di namen al geliche niwan ir zweir war ### ir wart erlovbet chvssen den wætlichen man ### im wart in alder werlde nie so liebe getan
| ### <Der> kvnech von Tenemarche der sprach sa ce stvnt ### diss vil hohen grvozes lit maneger vngesvnt ### des ich vil wol enpfinde von Sivrides hant ### got enlaz in nimmer mere chomn in miniv kvnges lant
###### 297 | ### Man hiez do allenthalben wichen von den wegn ### der scoenen Chrimhilde manegen chvenen degn ### sah man gezogenliche cer chirchen mit ir gan ### sit wart von ir gesceiden der vil wætliche man
###### 298 | ### Do gie si zvo dem mvenster ir volgete manech wip ### do was ovch so gecieret der kvneginne lip ### daz da hoher wnsche vil maneger wart verlorn ### si was da ce ovgenweide vil manegem rechen erchorn
###### 299 | ### Vil chvome erbeite Sivrit daz man da gesanch ### er mohte sinen sælden des immer sagen danch ### daz im div was so wæge di er in hercen trvoch ### ovch was er der scoenen holt von scvlden genvoch
| ### <Do> si chom voz dem mvnster sam er het ê getan ### man bat den degen chvenen wider zvo zir gan ### alrest begvnd im danchen div minnechliche meit ### daz er vor manegem helde so rehte herlichen streit
###### 301 | ### Nv lon iv got her Sivrit sprach daz vil scoene [304a] chint ### daz ir daz habt verdienet daz iv die rechen sint ### so holt mit rehten triwen als ich si hoere iehn ### do begvnder minechliche an frovn Chrimhilden sehn
###### 302 | ### Ich sol in immer dienen also sprach der degn ### vn– enwil min hovbet nimmer ê gelegn ### ih enwerbe nach ir willen sol ich min lebn han ### daz ist nach iwern hvlden min frov Chrimhilt getan
| ### <Inre> tagen zwelven der tage al ieslich ### sah man bi dem degene di maget loblich ### so si ce hove solde vor ir vriwenden gan ### der dienst wart dem rechen. dvrch groze liebe getan
###### 304 | ### Vrevde vn– wnne vil groezlichen scal ### sah man aller tægelich vor Gvnthers sal ### dar voz vn– ovch dar inne von manegem chvenen man ### Oertwin vn– Hagene vil grozer wnder began
###### 305 | ### Swes iemen pflegen wolde des waren si bereit ### mit vollechlicher maze di helde vil gemeit ### des wrden von den gesten di rechen wol bechant ### da von so was gezieret allez Gvntheres lant
| ### <Die> da wnde lagen die sah man fver gan ### si wolden chvrz wile mit dem gesinde han ### schirmen mit den <scilden> vn– schiezen manegen scaft ### des hvlfen in genvoge si heten groezliche chraft
###### 307 | ### In der hohgecite der wirt der hiez ir pflegn ### mit der besten spise er hete sich bewegn ### aller slahte scande di ie kvnech gewan ### man sah in vriwentliche zvo den sinen gesten gan
###### 308 | ### Er sprach. ir gvoten rechen ê daz ir sceidet hin ### so nemt ir mine gabe also stet min sin ### daz ichz immer diene versmahet <iv> niht min gvot ### daz wil ich mit iv teilen <des> han ich willigen mvot
| ### <Die> von Tenemarche di sprachen sa cehant ### ê daz wir wider riten heim in vnser lant ### wir gern stæter svone des ist vns rechen not ### wir han von iwern degenen manegen liebn vriwent tot
###### 310 | ### Livdegast geheilet siner wnden was ### der vogt von den Sahsen nach strite wol genas ### eteliche toten si liezen darn lant ### do gie der kvnec Gvnther da er Sivriden vant
| ### <Er> sprach zvo dem rechen nv ratet wie ich tvo ### di vnsern wider winnen die wellent riten frvo ### vnd gerent stæter svone an mich vn– mine man ### nv rata degen Sivrit waz dich des dvnche gvot getan
###### 312 | ### Waz mir die herren bieten daz wil ich dir sagen ### swaz fvnf hvndert moere goldes moehten getragen ### daz gebn si mir gerne wold ich si ledech lan ### do sprach der starche Sivrit daz wære vil vbele getan [304b]
###### 313 | ### Ir svlt si ledechlichen hinnen lazen varn ### vn– daz di rechen edele mere wol bewarn ### vientlichez riten her in iwer lant ### des lat iv gebn sicherheit hie der beider herrn hant
| ### Des rates wil ich volgen da mit si giengen dan ### den sinen vianden wart daz chvnt getan ### ir goldes gerte niemn daz si da bvten ê ### da heime ir lieben vriwenden was nach den her mveden we
###### 315 | ### Manege scilde volle man dar scazes trvoch ### er teiltes ane wage den vriwenden sin genvoch ### bi fvnf hvndert marchen vn– etslichen baz ### Gernot der vil chvene der riet Gvnthere daz
###### 316 | ### Vrlovp si alle namen also si wolden dan ### do sah man die geste fver Chrimhilde gan ### vn– ovch <da> vrovwe vote div kvneginne saz ### ezn wart nie degen noch mere gevrlovbet baz
###### 317 | ### Die herberge wrden lære do si von dannen ritten ### noch bestvont da heime mit herlichn siten ### der kvnech mit sinen magen vil manech edel man ### di sah man tægeliche zvo frovwen Chrimhilde gan
| ### <Vrlovp> do nemen wolde Sivrit der helt gvot ### er trvowete niht erwerben des er da hete mvot ### der kvnec daz sagen horte daz er wolde dan ### Giselher der ivnge in von der reise gar gewan
###### 319 | ### War woldet ir nv riten vil edel Sivrit ### belibet bi den rechen tvot des ich ivch bit ### bi Gvnthere dem kvnege vn– ovch bi sinen man ### hie ist vil scoener frovwen di sol man ivch gerne sehen lan
| ### Do sprach der starche Sivrit div ross div lazet stan ### ich <wolde> hinnen riten des wil ich ab gan ### vn– tragt ovch hin di schilde ia wold ich in min lant ### des hat mich her Giselher mit grozen triwen erwant
###### 321 | ### Svss beleip der chvene dvrch vriwende liebe da ### ia wær er in den landen ninder andrswa ### gewesen also sanfte da von daz gescach ### daz er nv tægeliche di scoenen Chrimhilden sach
###### 322 | ### Dvrch ir vnmazen scoene der herre da beleip ### mit maneger chvrze wile man nv di zit vertreip ### wan daz in twang ir minne div gab im diche not ### dar vmbe sit der chvene lach vil iæmerliche tot
###### 323 | ### Itniwoe mære sich hvoben vber Rin ### man sagte daz da wære manech scoene magedin ### der gedaht im eine erwerben Gvnther der kvnech gvot ### da von begvnde dem rechen vil sere hohen der mvot [305a]

<<< Übersicht <<< vorige Seite nächste Seite >>>